These data.frames give sample size tables calculated with
sampleN.TOST() for the 2x4x4 replicate crossover design
(2-treatment-4-sequence-4-period design).
The data.frame's can be accessed by their names or by data("name").
ct9.6.4 is Table 9.6.4 from Chow S.C., Liu J.P. "Design and Analysis of Bioavailability and Bioequivalence Studies", Third edition, CRC Press, Chapman & Hall, Boca Raton (2009) Additive model, theta1=-0.2, theta2=+0.2 (BE limits 0.80 - 1.20), approximate power via shifted non-central t-distribution.
ct9.6.8 is Table 9.6.8 from the same reference. Multiplicative model, theta1=0.8, theta2=1.25 (1/theta1), power via shifted non-central t-distribution. Attention! Chow and Liu's CV in case of multiplicative model is se (standard error) of residuals.