These data.frames give sample size tables calculated with
sampleN.TOST() for the parallel group design (2 groups).
The data.frame's can be accessed by their names or by data("name").
ctSJ.VIII.10 is Table VIII, column 'level of bioequivalence 10%' from S.A.Julious "Tutorial in Biostatistics Sample sizes for clinical trials with Normal data" 'Statistics in Medicine, Vol. 23, 1921-1986 (2004) Multiplicative model, theta1=0.9, theta2=1.1111 (1/theta1), target power=90%, power approximate via non-central t-distribution. Attention! Julious gives sample size per group.
ctSJ.VIII.20 is Table VIII from the same source column 'level of bioequivalence 20%' Multiplicative model, theta1=0.8, theta2=1.25 (1/theta1), target power=90%, power approximate via non-central t.
ctCW.III is Table III from Chow and Wang "On Sample Size Calculation in Bioequivalence Trials" J. Pharmacokin. Biopharm. Vol. 28(2), 155-169 (2001) Additive model, theta1=-0.2, theta2=+0.2 (BE limits 0.80 - 1.20), exact.
Seems the last reference is not very reliable (compare to the Table in the paper).